/* Copyright 1996, Jan D. Wolter and Steven R. Weiss, All Rights Reserved. */

/* Routine to read the conflist
 *
 * Mar 15, 1993 - Jan Wolter:  Original bbsread version
 * Dec  2, 1995 - Jan Wolter:  Ansification
 * Dec  4, 1995 - Jan Wolter:  Expansion of % in confname to confdir
 * Jan  3, 1996 - Jan Wolter:  Backtalk version
 */

#include "backtalk.h"

#include "sysdict.h"
#include "dict.h"
#include "str.h"
#include "ps_conflist.h"

char *expand_path(char *path);
void subchar(char *buf, char *string);

/* CFPATH -- Given a conference name, this returns the directory name.  It
 * returns null if the conference does not exist.  It exits with an error
 * message if some other weird error occurs.
 */

char *cfpath(char *name)
{
FILE *fp;
static char buf[BFSZ];
char *a;

	if ((fp= fopen(csdict(VAR_CONFLIST),"r")) == NULL)
		die("could not open %s",csdict(VAR_CONFLIST));

	/* Read and check magic code number */
	if (fgets(buf,BFSZ,fp) == NULL || strcmp(buf,"!<hl01>\n"))
		die("conference list %s has bad magic number",
			csdict(VAR_CONFLIST));

	/* Read and ignore default conference path - skipping comments */
	for (;;)
	{
		if (fgets(buf,BFSZ,fp) == NULL)
			die("conference list %s too short",
				csdict(VAR_CONFLIST));
		if (buf[0] != '#') break;
	}

	/* Search list of conferences */
	while (fgets(buf,BFSZ,fp) != NULL)
	{
		if (buf[0] == '#' || buf[0] == '\n') continue;

		if (match(name,buf,1))
		{
			if ((a= strchr(buf,':')) == NULL)
				die("bad line in conference list %s",
					csdict(VAR_CONFLIST));
			a++;
			*firstin(a,"\n \t")= '\0';
			fclose(fp);
			return expand_path(a);
		}
	}
	fclose(fp);
	return NULL;
}


/* SUBCHAR - Replace the first character of "buf" with the given string.
 * No checking for buffer overflow is done.
 */

void subchar(char *buf, char *string)
{
char *p= strchr(buf,'\0');
int len= strlen(string)-1;

	for (p= strchr(buf,'\0'); p > buf; p--)
		p[len]= *p;
	
	for (p= buf; *string != '\0'; p++, string++)
		*p= *string;
}


/* EXPAND_PATH - Expand out % sign in path.
 */

char *expand_path(char *path)
{
char *p;

	if ((p= strchr(path,'%')) != NULL)
		subchar(p,csdict(VAR_BBSDIR));
	return path;
}
